@@ -203,6 +203,7 @@ class MWCShellConfig(SetupTask):
         candidates = [
             ("bash", Path.home() / ".bash_profile"),
             ("bash", Path.home() / ".bash_rc"),
+            ("bash", Path.home() / ".bashrc"),
             ("zsh", Path.home() / ".zprofile"),
             ("zsh", Path.home() / ".zshrc"),
         ]
@@ -248,12 +249,17 @@ class InstallPoetry(SetupTask):
         click.echo(address("Installing poetry..."))
         run("curl -sSL https://install.python-poetry.org | python3 -", shell=True, check=True)
         click.echo(address("Installing poetry tab completions..."))
-        if shell == "bash":
-            Path("/etc/bash_completion.d").mkdir(exist_ok=True)
-            run("poetry completions bash > /etc/bash_completion.d/poetry", shell=True, check=True)
-        if shell == "zsh":
-            Path("~/.zfunc").mkdir(exist_ok=True)
-            run("poetry completions zsh > ~/.zfunc/_poetry", shell=True, check=True)
+        try:
+            if shell == "bash":
+                tab_completion_dir = Path("/etc/bash_completion.d")
+                tab_completion_dir.mkdir(exist_ok=True)
+                run("poetry completions bash > /etc/bash_completion.d/poetry", shell=True, check=True)
+            if shell == "zsh":
+                tab_completion_dir = Path("~/.zfunc")
+                tab_completion_dir.mkdir(exist_ok=True)
+                run("poetry completions zsh > ~/.zfunc/_poetry", shell=True, check=True)
+        except PermissionError:
+            click.echo(warn(f"Couldn't install tab completions for poetry. This is not a big deal."))
 
 class WriteShellConfig(SetupTask):
     description = "Write the MWC shell configuration file ~/.mwc_rc"
