@@ -10,7 +10,7 @@ def get_settings_path(settings_path=None):
     the MWC_CONFIG environment variable or the --config flag.
     """
     if settings_path:
-        return = Path(settings_path)
+        return Path(settings_path)
     elif "MWC_CONFIG" in os.environ:
         return Path(os.environ["MWC_CONFIG"])
     else:
